Summary:	Parallel ARPACK
Name:		parpack
Version:	96
Release:	7
License:	Open source
Group:		Applications/Library

SOURCE0:	arpack96.tar.bz2
SOURCE1:	patch.tar.bz2
SOURCE2:	parpack96.tar.bz2
SOURCE3:	ppatch.tar.bz2
SOURCE4:	ARmake.inc
SOURCE5:	arpack.pdf
SOURCE6:	arpack_ref.pdf
SOURCE7:	instruction.arpack
SOURCE8:	instruction.parpack
SOURCE9:	readme.arpack
SOURCE10:	readme.parpack

PATCH:		parpack-iternum-hack.patch
PATCH1:		parpack-pdlamch-hack.patch
PATCH2:		parpack-pznaup2.patch

URL:		http://www.caam.rice.edu/software/ARPACK/
BuildRoot:	/var/tmp/%{name}-%{version}-root-%(id -u -n)
BuildArch:	i386 x86_64
Obsoletes:	arpack
Provides:	arpack
Prefix:		/usr

%description
ARPACK is a collection of Fortran77 subroutines designed to solve large scale
eigenvalue problems.

The package is designed to compute a few eigenvalues and corresponding
eigenvectors of a general n by n matrix A. It is most appropriate for large
sparse or structured matrices A where structured means that a matrix-vector
product w <- Av requires order n rather than the usual order n2 floating point
operations. This software is based upon an algorithmic variant of the Arnoldi
process called the Implicitly Restarted Arnoldi Method (IRAM). When the matrix
A is symmetric it reduces to a variant of the Lanczos process called the
Implicitly Restarted Lanczos Method (IRLM). These variants may be viewed as a
synthesis of the Arnoldi/Lanczos process with the Implicitly Shifted QR
technique that is suitable for large scale problems. For many standard
problems, a matrix factorization is not required. Only the action of the
matrix on a vector is needed.

ARPACK software is capable of solving large scale symmetric, nonsymmetric, and
generalized eigenproblems from significant application areas. The software is
designed to compute a few (k) eigenvalues with user specified features such as
those of largest real part or largest magnitude. Storage requirements are on
the order of n*k locations. No auxiliary storage is required. A set of Schur
basis vectors for the desired k-dimensional eigen-space is computed which is
numerically orthogonal to working precision. Numerically accurate eigenvectors
are available on request. 

%prep
%setup -q -n ARPACK

# extract sources
cd ..
tar xjpf $RPM_SOURCE_DIR/arpack96.tar.bz2	# ARPACK source
tar xjpf $RPM_SOURCE_DIR/patch.tar.bz2		# ARPACK patches
tar xjpf $RPM_SOURCE_DIR/parpack96.tar.bz2	# PARPACK source
tar xjpf $RPM_SOURCE_DIR/ppatch.tar.bz2		# PARPACK patches
cd ARPACK
/bin/cp -pf $RPM_SOURCE_DIR/arpack*.pdf .

# apply local patches
patch -p1 < $RPM_SOURCE_DIR/parpack-iternum-hack.patch
patch -p1 < $RPM_SOURCE_DIR/parpack-pdlamch-hack.patch
patch -p1 < $RPM_SOURCE_DIR/parpack-pznaup2.patch

# set up ARmake.inc
sed -e 's|^\(home *=\).*$|\1 '`pwd`'|g' $RPM_SOURCE_DIR/ARmake.inc >ARmake.inc

# remove non-consistent mpif.h
find . -name mpif.h -exec rm -f {} \;

# hacky: modify UTIL/second.f to always returns 0
cat <<END >UTIL/second.f
      SUBROUTINE SECOND( T )
      REAL       T
      T = 0.0
      RETURN
      END
END

# The P[SD]LAMCH functions conflict with ScaLAPACK, we rename them
# by changing all occurrences of 'LAMCH' to 'LAMCA'
sed -i -e 's/\([Pp][SsDd][Ll][Aa][Mm][Cc]\)[Hh]/\1A/g' PARPACK/SRC/MPI/*.f

%build
make all
#(cd LAPACK; make all)
#ar dv libarpack.a slamch.o dlamch.o

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_libdir}
mkdir tmp
cd tmp
for l in libarpack libparpack; do
    rm -f *.o
    ar x ../${l}.a
    gcc -shared -o $RPM_BUILD_ROOT%{_libdir}/${l}.so *.o
done
cd ..
rm -rf tmp
/bin/chmod -R a+rX $RPM_BUILD_ROOT/.

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%post
/sbin/ldconfig

%postun
/sbin/ldconfig

%files
%doc README arpack*.pdf
%{_libdir}/libarpack.so
%{_libdir}/libparpack.so

%changelog
